===============================================================
2016-04-14 Grant Cross-Project Team Voting in CP Specifications
===============================================================

Introduction
------------

Since the inception of the :repo:`openstack/openstack-specs` the Technical
Committee has had privileges in OpenStack's gerrit review system to +2
a specification, as oppose to a +1 which any individual member of the community
can give today.

The goal of this resolution is to recognize the cross-project specification
liaison team by allowing them to have the ability to +2 specifications, since
they should know better than anyone else if a specification will work with
their project.


Previous Workflow
-----------------

When a cross-project specification is proposed, the cross-project specification
liaisons, are responsible for providing feedback when a specification involves
their project.

Once there is consensus among the cross-project specification liaisons, the
specification is added to the Technical Committee's meeting agenda to be rubber
stamped to be merged.


New Workflow
------------

When a cross-project specification is proposed, the cross-project specification
liaisons will review it as usual. There will be a list of projects that are
known to be involved at the time within a specification. Those cross-project
specification liaisons will need to sign off on the specification with a +2.

Assuming there is consensus with those that are involved, the specification
will be merged (Workflow+1) by the cross-project chair after final discussion
in the `cross-project meeting
<https://wiki.openstack.org/wiki/Meetings/CrossProjectMeeting>`_.

In the cases where consensus cannot be met with the projects involved
with a cross-project specification, the specification can be appealed to the
Technical Committee to discuss a final decision.

Projects that have nothing to do with the specification may provide feedback in
the review, but the decision is up to those that will ultimately have to
implement the specification in their project.
